/*
 * This file is part of the ALT project, module Alt-Customize-Branding.
 * Copyright (c) BaseALT Ltd 2020 Pavel Moseev <mars@altlinux.org>
 *
 * This is free software; you can use this application under the GNU
 * General Public License, version 3. See the file "COPYING" for the
 * exact licensing terms.
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QGraphicsScene>
#include <QPoint>
#include <QGraphicsView>
#include <QMouseEvent>
#include <QGraphicsItem>
#include <QGraphicsSceneMouseEvent>
#include <QGraphicsRectItem>
#include <QImage>

#include <kauthaction.h>
#include <KAuthAction>
#include <KAuthExecuteJob>
#include <KAuth>
#include <QMessageBox>
#include <QTranslator>

QT_BEGIN_NAMESPACE
namespace Ui { class MainWindow; }
QT_END_NAMESPACE

using namespace KAuth;

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    MainWindow(QWidget *parent = nullptr);
    ~MainWindow();

private slots:
    void on_Button_Close_clicked();
    void on_Button_Apply_clicked();
    void on_button_viewPlymouthImage_clicked();
    void on_button_openPlymouthImage_clicked();
    void on_button_viewNewLogo_clicked();
    void on_button_openNewLogo_clicked();
    void on_Button_Clear_clicked();

public Q_SLOTS:
    void jobFinished(KJob* kjob);

private:
    Ui::MainWindow *ui;

private:
    QString openFileToChangeBranding(QString pathFromLineEdit);
    void viewFileToChangeBranding(QString pathToFile);
    void viewLogoToChangeBranding();
    void logoCoordsDetermination();
    QString createNewImage(QString imageFile, QString logoFile);
    QImage mergeImages(const QImage& backImage, const QImage& logoImage);
    QString resizeImage(QString newImage, double arg1, double arg2);
    QString convertImageToJpg(QString arg1);

private:
    QPixmap image;
    QImage  *imageObject;
    QGraphicsScene *scene;
    // QGraphicsView *view;
    QGraphicsPixmapItem* item;

private:
    virtual void resizeEvent(QResizeEvent *event) override;
    QString fileTCBPathInScene_;
    bool logoInScene_ = false;
    bool addLogoButtonActivated_ = false;
    QString appName_ = QLatin1String("alt-customize-branding");
    QString appTmpSettingsDir_ = QLatin1String("/tmp/") + appName_ + QLatin1String("/");
    QString appSettingsDir_ = QLatin1String("/var/lib/") + appName_ + QLatin1String("/");
    int currentItemX_; // logo coordinates
    int currentItemY_;
    int myTimerId_;
	bool setScene_ = false;

protected:
    //void mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent);
    //void mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent);
    void timerEvent(QTimerEvent *event) override;
    // void showEvent(QShowEvent *event) override;
    // void hideEvent(QHideEvent *event) override;

public:
    QTranslator *qtranslator;
    QTranslator *app_translator;
    void useTranslator(QTranslator* translator, const QString &domain);
    void useAppType(QString appName);

};
#endif // MAINWINDOW_H



